==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-drive-rename/translations/peony-drive-rename_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>Peony::DriveRename</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">设备重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="166"/>
        <location filename="../drive-rename.cpp" line="178"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="178"/>
        <source>Device name:</source>
        <translation>Nom de l’appareil :</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="182"/>
        <location filename="../drive-rename.cpp" line="190"/>
        <location filename="../drive-rename.cpp" line="196"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="182"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>Le renommage ne peut pas commencer par une virgule, veuillez entrer à nouveau !</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="190"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>Le nom de l’appareil dépasse la limite de caractères, le renommage a échoué !</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="196"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>Le changement de nom démontera l’appareil. Voulez-vous continuer&#xa0;?</translation>
    </message>
    <message>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="vanished">可能设备不支持重命名操作，重命名失败！</translation>
    </message>
    <message>
        <source>Failed to rename!</source>
        <translation type="vanished">重命名失败！</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRenamePlugin</name>
    <message>
        <location filename="../driverenameplugin.h" line="21"/>
        <source>drive rename</source>
        <translation>Renommer le lecteur</translation>
    </message>
</context>
<context>
    <name>Peony::DriverAction</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>Peony::SendToPlugin</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../drive-rename.cpp" line="328"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="328"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation>L’appareil peut ne pas prendre en charge l’opération de renommage, le renommage a échoué !</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.20.0.0.orig.tar.gz: peony-extensions-4.20.0.0/peony-drive-rename/translations/peony-drive-rename_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>Peony::DriveRename</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">设备重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="181"/>
        <location filename="../drive-rename.cpp" line="193"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="193"/>
        <source>Device name:</source>
        <translation>Nom de l’appareil :</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="197"/>
        <location filename="../drive-rename.cpp" line="205"/>
        <location filename="../drive-rename.cpp" line="211"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="197"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>Le renommage ne peut pas commencer par une virgule, veuillez entrer à nouveau !</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="205"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>Le nom de l’appareil dépasse la limite de caractères, le renommage a échoué !</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="211"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>Le changement de nom démontera l’appareil. Voulez-vous continuer&#xa0;?</translation>
    </message>
    <message>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="vanished">可能设备不支持重命名操作，重命名失败！</translation>
    </message>
    <message>
        <source>Failed to rename!</source>
        <translation type="vanished">重命名失败！</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRenamePlugin</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">Renommer le lecteur</translation>
    </message>
    <message>
        <location filename="../driverenameplugin.h" line="41"/>
        <source>Drive rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::DriverAction</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>Peony::SendToPlugin</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../drive-rename.cpp" line="343"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="343"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation>L’appareil peut ne pas prendre en charge l’opération de renommage, le renommage a échoué !</translation>
    </message>
</context>
</TS>
